from setuptools import setup

setup(name='pikaManagement',
      version='0.1.2',
    description='connect and consume with rabbitMq(pika)',
    author='zeinab',
    author_email='zeinabzarei73@gmail.com',
      # license='MIT',
      packages=['pikaManagement'],
      install_requires=['pika'],
      # zip_safe=False
)